| Title: | Interactive Presentation for Working with Normal Distribution |
|---|---|
| Description: | An interactive presentation on the topic of normal distribution using 'rmarkdown' and 'shiny' packages. It is helpful to those who want to learn normal distribution quickly and get a hands on experience. The presentation has a template for solving problems on normal distribution. Runtime examples are provided in the package function as well as at <https://kartikeyastat.shinyapps.io/NormalDistribution/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-06-06 09:26:05 UTC |
| Source: | https://github.com/cran/NDP |
NDP() loads interactive user interface built using R 'shiny'.
NDP()NDP()
Start NDP
The interactive user interface is to provide an easy way for people who are learning normal distribution. Includes example data for testing out a few example analysis.
Nothing
if(interactive()){ library(rmarkdown) NDP() }if(interactive()){ library(rmarkdown) NDP() }